@@ -25,7 +25,7 @@
 #' Class providing a variable annuity pricing engine where the underlying
 #' reference fund and interest rates are specified by an arbitrary
 #' system of stochastic differential equations. In contrast the intensity
-#' of mortality is determinitic and given by the Weibull function.
+#' of mortality is deterministic and given by the Weibull function.
 #' The financial paths are simulated by means of the
 #' \href{https://CRAN.R-project.org/package=yuima}{yuima} package. \cr
 #' The value of the VA contract is estimated by means of the Monte Carlo
@@ -108,15 +108,15 @@
 #'    the point estimates}
 #'    \item{\code{npaths}}{\code{numeric} scalar with the number of MC
 #'    simulations to run}
-#'    \item{\code{lower}}{\code{numeric} scalar with the fee corresponding
-#'    to  the lower end of the bisection interval}
-#'    \item{\code{upper}}{\code{numeric} scalar with the fee corresponding
-#'    to the upper end of the bisection interval}
+#'    \item{\code{lower}}{\code{numeric} scalar with the lower fee corresponding
+#'    to positive end of the bisection interval}
+#'    \item{\code{upper}}{\code{numeric} scalar with the upper fee corresponding
+#'    to the negative end of the bisection interval}
 #'    \item{\code{mixed}}{\code{boolean} specifying if the mixed method has
 #'    to be used. The default is \code{FALSE}}
 #'    \item{\code{tol}}{\code{numeric} scalar with the tolerance of the
 #'    bisection algorithm. Default is \code{1e-4}}
-#'    \item{\code{nmax}}{positive \code{integer} with the maximun number of
+#'    \item{\code{nmax}}{positive \code{integer} with the maximum number of
 #'    iterations of the bisection algorithm}
 #'    \item{\code{simulate}}{boolean specifying if financial and mortality
 #'    paths should be simulated.}
@@ -268,11 +268,12 @@ va_sde_engine2 <- R6::R6Class("va_sde_engine2", inherit = va_engine,
     c2 <- private$mu_2
     t_yrs  <- head(private$the_product$times_in_yrs(), -1)
     #Deterministic intensity of mortality (Weibull)
-    mu <- (c1 ^ (-c2)) * c2 * ((age + t_yrs) ^ (c2 - 1))
-    #Integrals of the intensity of mortality
-    dt <- diff(t_yrs)
-    mu_ <- head(mu, -1)
-    mu_integrals <- cumsum(c(0, mu_ * dt))
+    integrand <- function(t) {
+      (c1 ^ (-c2)) * c2 * ((age + t) ^ (c2 - 1))
+    }
+    mu_integrals <- sapply(t_yrs, function(u) {
+      stats::integrate(integrand, 0, u)$value
+    })
     mu_integrals
   },
   death_time = function(i){
